Learn R Programming

ctrialsgov (version 0.2.7)

ctgov_query_terms: Query the ClinicalTrials.gov dataset

Description

Returns a list showing the available category levels for querying the data with the ctgov_query function.

Usage

ctgov_query_terms()

Arguments

Value

a named list of allowed categorical values for the query