Takes one or more vectors of text and returns a similarity matrix.
ctgov_text_similarity(
...,
max_terms = 10000,
tolower = TRUE,
min_df = 0,
max_df = 1
)a distance matrix
one or more vectors of text to search; must all be the same length
maximum number of terms to consider for keywords
should keywords respect the case of the raw terms
minimum proportion of documents that a term should be present in to be included in the keywords
maximum proportion of documents that a term should be present in to be included in the keywords