Takes one or more vectors of text and returns a vector of keywords.
ctgov_tfidf(
...,
max_terms = 10000,
tolower = TRUE,
nterms = 5L,
min_df = 0,
max_df = 1
)a character vector of detected keywords
one or more vectors of text to search; must all be the same length
maximum number of terms to consider for keywords
should keywords respect the case of the raw terms
number of keyord terms to include
minimum proportion of documents that a term should be present in to be included in the keywords
maximum proportion of documents that a term should be present in to be included in the keywords