powered by
Returns a list showing the available category levels for querying the data with the ctgov_query function.
ctgov_query
ctgov_query_terms()
a named list of allowed categorical values for the query